@@ -5,6 +5,13 @@
 Utilities for working with the Python Package Index (PyPI).
 
 .. versionadded:: 0.2.0
+
+.. seealso::
+
+	`pypi-json`_, which provides some of the functionality from this module but with a reusable HTTP session and
+	support for authentication with other endpoints (such as a private package repository).
+
+.. _pypi-json: https://pypi-json.readthedocs.io/en/latest/
 """
 #
 #  Copyright © 2020-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
@@ -219,7 +226,7 @@ def get_releases_with_digests(pypi_name: str) -> Dict[str, List[FileURL]]:
 	return pypi_releases
 
 
-def get_file_from_pypi(url: Union[URL, str], tmpdir: PathLike):
+def get_file_from_pypi(url: Union[URL, str], tmpdir: PathLike) -> None:
 	"""
 	Download the file with the given URL into the given (temporary) directory.
 
