@@ -33,7 +33,7 @@ Utilities for working with :pep:`508` requirements.
 # stdlib
 import warnings
 from abc import ABC
-from typing import Any, Callable, Dict, Iterable, Iterator, List, Optional, Set, Tuple, Union, overload
+from typing import Any, Callable, Dict, Iterable, Iterator, List, Optional, Set, Tuple, Union, cast, overload
 
 # 3rd party
 import dom_toml
@@ -45,7 +45,7 @@ from domdf_python_tools.stringlist import DelimitedList, StringList
 from domdf_python_tools.typing import PathLike
 from packaging.markers import default_environment
 from packaging.requirements import InvalidRequirement, Requirement
-from packaging.specifiers import Specifier, SpecifierSet
+from packaging.specifiers import BaseSpecifier, Specifier, SpecifierSet
 from typing_extensions import Literal
 
 # this package
@@ -78,14 +78,14 @@ class ComparableRequirement(Requirement):
 	"""
 
 	@staticmethod
-	def _check_equal_not_none(left: Optional[Any], right: Optional[Any]):
+	def _check_equal_not_none(left: Optional[Any], right: Optional[Any]) -> bool:
 		if not left or not right:
 			return True
 		else:
 			return left == right
 
 	@staticmethod
-	def _check_marker_equality(left: Optional[Any], right: Optional[Any]):
+	def _check_marker_equality(left: Optional[Any], right: Optional[Any]) -> bool:
 		if left is not None and right is not None:
 			for left_mark, right_mark in zip(left._markers, right._markers):
 				if str(left_mark) != str(right_mark):
@@ -169,7 +169,7 @@ class ComparableRequirement(Requirement):
 
 class _OperatorLookup(Dict[str, DelimitedList[Specifier]]):
 
-	def __setitem__(self, key: str, value):
+	def __setitem__(self, key: str, value: Any) -> None:
 		if key not in operator_symbols:
 			raise KeyError(f"Invalid operator symbol {key!r}")
 
@@ -185,17 +185,18 @@ class _OperatorLookup(Dict[str, DelimitedList[Specifier]]):
 		return super().__getitem__(item)
 
 
-def resolve_specifiers(specifiers: Iterable[Specifier]) -> SpecifierSet:
-	"""
+def resolve_specifiers(specifiers: Iterable[BaseSpecifier]) -> SpecifierSet:
+	r"""
 	Resolve duplicated and overlapping requirement specifiers.
 
 	:param specifiers:
+	:type specifiers: :class:`~typing.Iterable`\[:class:`~.packaging.specifiers.Specifier`]
 	"""
 
 	operator_lookup = _OperatorLookup()
 	spec: Specifier
 
-	for spec in specifiers:
+	for spec in cast(Iterable[Specifier], specifiers):
 		if spec.operator in operator_symbols:
 			operator_lookup[spec.operator].append(spec)
 
@@ -298,6 +299,7 @@ def combine_requirements(
 			req = ComparableRequirement(str(req))
 
 		req.name = normalize_func(req.name)
+		_denormalize_ruamel(req)
 
 		if req.name in merged_requirements:
 			other_req = merged_requirements[merged_requirements.index(req.name)]  # type: ignore
@@ -412,6 +414,7 @@ def parse_requirements(
 			try:
 				req = ComparableRequirement(line)
 				req.name = normalize_func(req.name)
+				_denormalize_ruamel(req)
 				parsed_requirements.add(req)
 			except InvalidRequirement:
 				invalid_lines.append(line)
@@ -456,7 +459,7 @@ class RequirementsManager(ABC):
 		self.req_file = self.prep_req_file()
 		self.target_requirements = set(self.target_requirements)
 
-	def prep_req_file(self):
+	def prep_req_file(self) -> PathPlus:
 		"""
 		Create the requirements file if necessary, and in any case return its filename.
 		"""
@@ -737,3 +740,9 @@ def parse_pyproject_extras(
 			for k,
 			v in dependencies.items()
 			}
+
+
+def _denormalize_ruamel(req: Requirement):
+	if req.name in {"ruamel-yaml", "ruamel_yaml"}:
+		# Special case to work around issue with Poetry
+		req.name = "ruamel.yaml"
